import 'dart:math';

import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/widgets/backgrounds/hx_gradient_bg.dart';

class HxAnimatedBg extends StatefulWidget {
  final double height;
  final double width;
  final Alignment alignment;

  const HxAnimatedBg({
    this.height = double.maxFinite,
    this.width = double.maxFinite,
    this.alignment = Alignment.center,
  });

  @override
  State<HxAnimatedBg> createState() => _HxAnimatedBgState();
}

class _HxAnimatedBgState extends State<HxAnimatedBg> with SingleTickerProviderStateMixin {
  late AnimationController _controller;

  double rotationAngle = 20;
  List<double> offSetPosition = [
    0,
    0,
  ];

  @override
  void initState() {
    super.initState();

    _controller = AnimationController(
      duration: const Duration(minutes: 1),
      vsync: this,
    );

    _controller.repeat(reverse: true);

    _controller.addListener(() {
      setState(() {
        rotationAngle = _controller.value * 2;
        offSetPosition[0] = _controller.value;
        offSetPosition[1] = _controller.value;
      });
    });
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final MediaQueryData queryData = MediaQuery.of(context);
    //682,9
    //457,1
    return Stack(
      children: <Widget>[
        const HxGradientBg(
          height: 200, //queryData.size.height * 0.3,
        ),
        AnimatedHexagon(
          offSetPosition: offSetPosition,
          rotationAngle: rotationAngle,
          topDistance: queryData.size.height * 0.205,
          leftDistance: queryData.size.width * 0.35,
          offset: Offset(-offSetPosition[0] * 130, offSetPosition[1]),
          colors: const [
            Color.fromRGBO(255, 255, 255, 0.13),
            Color.fromRGBO(255, 255, 255, 0.03),
          ],
        ),
        AnimatedHexagon(
          offSetPosition: offSetPosition,
          rotationAngle: -(rotationAngle * rotationAngle / 2),
          bottomDistance: queryData.size.height * 0.225,
          offset: Offset(offSetPosition[0] * 130, offSetPosition[1]),
          colors: const [
            Color.fromRGBO(255, 255, 255, 0.13),
            Color.fromRGBO(255, 255, 255, 0.03),
          ],
        ),
        AnimatedHexagon(
          offSetPosition: offSetPosition,
          rotationAngle: -(rotationAngle * 0.8),
          bottomDistance: queryData.size.height * 0.2,
          leftDistance: queryData.size.width * 0.660,
          offset: Offset(offSetPosition[0] * 0.2, offSetPosition[1] * 200),
          colors: const [
            Color.fromRGBO(255, 255, 255, 0.13),
            Color.fromRGBO(255, 255, 255, 0.03),
          ],
        ),
      ],
    );
  }
}

class AnimatedHexagon extends StatelessWidget {
  AnimatedHexagon({
    required this.offSetPosition,
    required this.rotationAngle,
    required this.colors,
    required this.offset,
    this.topDistance,
    this.bottomDistance,
    this.leftDistance,
    this.rightDistance,
  });

  final List<double> offSetPosition;
  final double rotationAngle;
  double? topDistance;
  double? bottomDistance;
  double? leftDistance;
  double? rightDistance;
  List<Color> colors;
  Offset offset;

  @override
  Widget build(BuildContext context) {
    return Positioned(
      top: topDistance,
      left: leftDistance,
      right: rightDistance,
      bottom: bottomDistance,
      child: Transform.translate(
        offset: offset,
        child: Transform.rotate(
          angle: -rotationAngle,
          child: ClipPath(
            clipper: _Hexagon(),
            child: Container(
              decoration: BoxDecoration(
                gradient: LinearGradient(
                  begin: Alignment.topCenter,
                  end: Alignment.bottomCenter,
                  colors: colors,
                ),
              ),
              width: 160,
              height: 160,
            ),
          ),
        ),
      ),
    );
  }
}

class _Hexagon extends CustomClipper<Path> {
  @override
  Path getClip(Size size) {
    final path = Path();
    path.lineTo(size.width * 0.25, 0);
    path.lineTo(size.width * 0.75, 0);
    path.lineTo(size.width, size.height * sqrt(3) / 4);

    path.lineTo(size.width * 0.75, size.height * sqrt(3) / 2);
    path.lineTo(size.width * 0.25, size.height * sqrt(3) / 2);
    path.lineTo(0, size.height * sqrt(3) / 4);
    path.lineTo(size.width * 0.25, 0);
    path.close();
    return path;
  }

  @override
  bool shouldReclip(covariant CustomClipper<Path> oldClipper) => false;
}
