import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_utils.dart';
import 'package:hx_components_flutter/src/widgets/hx_button.dart';
import 'package:hx_components_flutter/src/widgets/hx_text.dart';

class HxAlertDialog extends StatelessWidget {
  final String titulo;
  final String mensagem;
  final String textoBotaoConfirmar;
  final String textoBotaoCancelar;

  const HxAlertDialog({
    super.key,
    this.titulo = 'Confirmar',
    this.mensagem = 'Deseja realmente confirmar esta ação?',
    this.textoBotaoConfirmar = 'Sim',
    this.textoBotaoCancelar = 'Não',
  });

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      elevation: 4,
      insetPadding: const EdgeInsets.only(top: 24),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(20),
      ),
      contentPadding: const EdgeInsets.all(24),
      actionsPadding: const EdgeInsets.only(
        bottom: 20,
        left: 24,
        right: 24,
      ),
      title: HxText.heading1(titulo, color: kcPrimaryColor),
      content: HxText(mensagem),
      actions: [
        Column(
          children: [
            const Divider(),
            const SizedBox(
              height: 20,
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Expanded(
                  child: HxButton.secondary(
                    title: textoBotaoCancelar,
                    onTap: () {
                      Navigator.of(context).pop(false);
                    },
                  ),
                ),
                const SizedBox(
                  width: 16,
                ),
                Expanded(
                  child: HxButton.primary(
                    title: textoBotaoConfirmar,
                    onTap: () {
                      Navigator.of(context).pop(true);
                    },
                  ),
                ),
              ],
            ),
          ],
        )
      ],
    );
  }
}
