import 'package:flutter/material.dart';

import 'package:hx_components_flutter/hx_components.dart';

import 'package:hx_components_flutter/src/shared/app_colors.dart';

class HxListItem extends StatelessWidget {
  final String title;
  final String description;
  final IconData icon;
  final VoidCallback onTap;
  Color? bgColor;
  Color textColor;
  Color? arrowIconColor;
  Color borderColor;
  Color? clickColor;

  HxListItem.white({
    required this.title,
    required this.onTap,
    this.icon = Icons.arrow_forward_ios,
    this.description = '',
  })  : bgColor = kcBackgroundColor,
        textColor = kcMainText,
        arrowIconColor = kcDarkGrey,
        borderColor = kcLightGrey,
        clickColor = kcPrimaryColor;

  HxListItem.blue({
    required this.title,
    required this.onTap,
    this.icon = Icons.arrow_forward_ios,
    this.description = '',
  })  : bgColor = kcPrimaryColor,
        textColor = kcBackgroundColor,
        arrowIconColor = kcBackgroundColor,
        borderColor = kcPrimaryColor,
        clickColor = null;

  @override
  Widget build(BuildContext context) {
    return Material(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(10),
        side: BorderSide(color: borderColor, width: 2.0),
      ),

      color: bgColor,

      //height: MediaQuery.of(context).size.height * 0.18,

      child: InkWell(
        onTap: onTap,
        splashColor: clickColor,
        //hoverColor: bgColor,
        borderRadius: BorderRadius.circular(10),
        child: Ink(
          padding: const EdgeInsets.all(15.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Row(
                children: [
                  Container(
                    padding: const EdgeInsets.all(8.0),
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(12.0),
                      color: kcLightGrey,
                    ),
                    child: Icon(
                      icon,
                      color: kcSecondaryColor,
                      size: MediaQuery.of(context).size.width * 0.08,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.only(left: 10.0),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        HxText.heading3(
                          title,
                          fontWeight: FontWeight.normal,
                          color: textColor,
                        ),
                        if (description.isEmpty)
                          Container()
                        else
                          HxText.custom(
                            description,
                            style: TextStyle(
                              color: bgColor == kcBackgroundColor ? kcDarkGrey : kcBackgroundColor,
                              fontSize: 12.0,
                            ),
                          )
                      ],
                    ),
                  ),
                ],
              ),
              Icon(
                Icons.arrow_forward_ios,
                size: 15.0,
                color: arrowIconColor,
              ),
            ],
          ),
        ),
      ),
    );
  }
}
